==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/plugins/Input/modplug/translations/modplug_plugin_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="hu_HU">
<context>
    <name>DecoderModPlugFactory</name>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="47"/>
        <source>ModPlug Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="53"/>
        <source>ModPlug Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="119"/>
        <source>About ModPlug Audio Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="120"/>
        <source>Qmmp ModPlug Audio Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="121"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="122"/>
        <source>Based on the Modplug Plugin for Xmms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="123"/>
        <source>Modplug Plugin developers:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="124"/>
        <source>Olivier Lapicque &lt;olivierl@jps.net&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="125"/>
        <source>Kenton Varda &lt;temporal@gauge3d.org&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="126"/>
        <source>Konstanty Bialkowski &lt;konstanty@ieee.org&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ModPlugMetaDataModel</name>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="71"/>
        <source>File name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="142"/>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="147"/>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="148"/>
        <source>Speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="149"/>
        <source>Tempo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="150"/>
        <location filename="../modplugmetadatamodel.cpp" line="171"/>
        <source>Samples</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="151"/>
        <location filename="../modplugmetadatamodel.cpp" line="180"/>
        <source>Instruments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="152"/>
        <source>Patterns</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="153"/>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="185"/>
        <source>Comment</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>ModPlug Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="33"/>
        <source>Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>16 bit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="58"/>
        <source>8 bit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="74"/>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="80"/>
        <source>Stereo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="87"/>
        <source>Mono (downmix)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="103"/>
        <source>Resampling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="109"/>
        <source>Nearest (fastest)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="116"/>
        <source>Linear (fast)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="123"/>
        <source>Spline (good quality)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="130"/>
        <source>8-tap Fir (extremely high quality)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="146"/>
        <source>Sampling Rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="152"/>
        <source>48000 Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="159"/>
        <source>44100 Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="166"/>
        <source>22050 Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="173"/>
        <source>11025 Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="184"/>
        <source>Effects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="190"/>
        <source>Reverb</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="202"/>
        <location filename="../settingsdialog.ui" line="467"/>
        <source>Depth (%)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="234"/>
        <location filename="../settingsdialog.ui" line="368"/>
        <location filename="../settingsdialog.ui" line="499"/>
        <location filename="../settingsdialog.ui" line="618"/>
        <source>0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="260"/>
        <location filename="../settingsdialog.ui" line="519"/>
        <source>Delay (ms)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="292"/>
        <source>40</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="324"/>
        <source>Bass Boost</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="336"/>
        <source>Amount (%)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="394"/>
        <source>Range (Hz)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="426"/>
        <source>10</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="458"/>
        <source>Surround</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="551"/>
        <source>5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="577"/>
        <source>Preamp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="586"/>
        <source>Volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="656"/>
        <source>Note: Setting the preamp
too high may cause clipping!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="671"/>
        <source>Misc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="677"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="683"/>
        <source>Use filename as song title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="690"/>
        <source>Noise reduction</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="700"/>
        <source>Fast playlist info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="710"/>
        <source>Play Amiga MOD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="720"/>
        <source>Looping</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="726"/>
        <source>Don&apos;t loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="733"/>
        <source>Loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="750"/>
        <source>time(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="770"/>
        <source>Loop forever</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_1.4.4.orig.tar.bz2: qmmp-1.4.4/src/plugins/Input/modplug/translations/modplug_plugin_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>DecoderModPlugFactory</name>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="46"/>
        <source>ModPlug Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="52"/>
        <source>ModPlug Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="136"/>
        <source>About ModPlug Audio Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="137"/>
        <source>Qmmp ModPlug Audio Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="138"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="139"/>
        <source>Based on the Modplug Plugin for Xmms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="140"/>
        <source>Modplug Plugin developers:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="141"/>
        <source>Olivier Lapicque &lt;olivierl@jps.net&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="142"/>
        <source>Kenton Varda &lt;temporal@gauge3d.org&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="143"/>
        <source>Konstanty Bialkowski &lt;konstanty@ieee.org&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ModPlugMetaDataModel</name>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="71"/>
        <source>Speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="72"/>
        <source>Tempo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="73"/>
        <location filename="../modplugmetadatamodel.cpp" line="94"/>
        <source>Samples</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="74"/>
        <location filename="../modplugmetadatamodel.cpp" line="103"/>
        <source>Instruments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="75"/>
        <source>Patterns</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="76"/>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="108"/>
        <source>Comment</source>
        <translation>Megjegyzés</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>ModPlug Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="33"/>
        <source>Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>16 bit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="58"/>
        <source>8 bit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="74"/>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="80"/>
        <source>Stereo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="87"/>
        <source>Mono (downmix)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="103"/>
        <source>Resampling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="109"/>
        <source>Nearest (fastest)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="116"/>
        <source>Linear (fast)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="123"/>
        <source>Spline (good quality)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="130"/>
        <source>8-tap Fir (extremely high quality)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="146"/>
        <source>Sampling Rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="152"/>
        <source>48000 Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="159"/>
        <source>44100 Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="166"/>
        <source>22050 Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="173"/>
        <source>11025 Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="184"/>
        <source>Effects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="190"/>
        <source>Reverb</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="202"/>
        <location filename="../settingsdialog.ui" line="467"/>
        <source>Depth (%)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="234"/>
        <location filename="../settingsdialog.ui" line="368"/>
        <location filename="../settingsdialog.ui" line="499"/>
        <location filename="../settingsdialog.ui" line="618"/>
        <source>0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="260"/>
        <location filename="../settingsdialog.ui" line="519"/>
        <source>Delay (ms)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="292"/>
        <source>40</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="324"/>
        <source>Bass Boost</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="336"/>
        <source>Amount (%)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="394"/>
        <source>Range (Hz)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="426"/>
        <source>10</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="458"/>
        <source>Surround</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="551"/>
        <source>5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="577"/>
        <source>Preamp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="586"/>
        <source>Volume</source>
        <translation>Hangerő</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="656"/>
        <source>Note: Setting the preamp
too high may cause clipping!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="671"/>
        <source>Misc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="677"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="683"/>
        <source>Use filename as song title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="690"/>
        <source>Noise reduction</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="700"/>
        <source>Fast playlist info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="710"/>
        <source>Play Amiga MOD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="720"/>
        <source>Looping</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="726"/>
        <source>Don&apos;t loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="733"/>
        <source>Loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="750"/>
        <source>time(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="770"/>
        <source>Loop forever</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
